#
# spec file for package profanity
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           profanity
Version:        0.8.1
Release:        lp152.1.3
Summary:        Console-based XMPP client
License:        SUSE-GPL-3.0+-with-openssl-exception
Group:          Productivity/Networking/Instant Messenger
URL:            https://profanity-im.github.io
Source:         https://github.com/profanity-im/profanity/releases/download/%{version}/profanity-%{version}.tar.gz
Source1:        profanity-rpmlintrc
BuildRequires:  glib2-devel >= 2.26
BuildRequires:  gtk2-devel
BuildRequires:  libcurl-devel
BuildRequires:  libexpat-devel
BuildRequires:  libgpgme-devel
BuildRequires:  libmesode-devel >= 0.9.2
BuildRequires:  libnotify-devel
BuildRequires:  libotr-devel
BuildRequires:  libsignal-protocol-c-devel >= 2.3.1
BuildRequires:  libuuid-devel
BuildRequires:  ncurses-devel
BuildRequires:  python3-devel
BuildRequires:  readline-devel
Requires:       libmesode0 >= 0.9.2
Requires:       profanity-binary = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Profanity is a console-based XMPP client written in C using ncurses,
and inspired by Irssi.

%package mini
Summary:        Console-based XMPP client
Group:          Productivity/Networking/Instant Messenger
Requires:       profanity = %{version}
Requires(post): update-alternatives
Requires(preun): update-alternatives
Provides:       profanity-binary = %{version}-%{release}

%description mini
Profanity is a console-based XMPP client written in C using ncurses,
and inspired by Irssi.
This package holds a minimal version, with most options not compiled
in to have fewer dependencies. It is thus well suited for headless
servers.

%package standard
Summary:        Console-based XMPP client
Group:          Productivity/Networking/Instant Messenger
Requires:       profanity = %{version}
Requires(post): update-alternatives
Requires(preun): update-alternatives
Provides:       profanity-binary = %{version}-%{release}

%description standard
Profanity is a-console based XMPP client written in C using ncurses,
and inspired by Irssi.

This package holds the standard version.
Including:
 * Desktop notifications (OSD)
 * Tray icon

%prep
%setup -q -n %{name}-%{version}
sed -i -e "s/python-config/python3-config/g" configure

%build
%configure PYTHON_VERSION=3 \
	--enable-notifications \
	--with-themes \
	--enable-otr \
	--enable-pgp \
	--enable-omemo \
	--enable-python-plugins \
	--enable-c-plugins \
	--enable-plugins \
	--enable-icons

make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm %{buildroot}%{_libdir}/libprofanity.la

mv %{buildroot}%{_bindir}/profanity{,-standard}

make clean

%configure PYTHON_VERSION=3 \
	--disable-notifications \
	--with-themes \
	--enable-otr \
	--enable-pgp \
	--enable-omemo \
	--enable-python-plugins \
	--enable-c-plugins \
	--enable-plugins \
	--disable-icons

make %{?_smp_mflags}
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm %{buildroot}%{_libdir}/libprofanity.la

mv %{buildroot}%{_bindir}/profanity{,-mini}

# u-a handling
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
ln -s profanity %{buildroot}%{_sysconfdir}/alternatives/profanity
ln -s profanity %{buildroot}%{_bindir}/profanity

%files
%defattr(-,root,root)
%{_mandir}/man1/profanity.1%{ext_man}
%dir %{_datadir}/profanity/
%dir %{_datadir}/profanity/themes/
%dir %{_datadir}/profanity/icons/
%{_datadir}/profanity/themes/*
%{_datadir}/profanity/icons/*
# for now we will have them here
%{_libdir}/libprofanity.so*

%{_includedir}/profapi.h

%files mini
%defattr(-,root,root)
%ghost %{_sysconfdir}/alternatives/profanity
%ghost %{_bindir}/profanity
%{_bindir}/profanity-mini

%files standard
%defattr(-,root,root)
%ghost %{_sysconfdir}/alternatives/profanity
%ghost %{_bindir}/profanity
%{_bindir}/profanity-standard

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post mini
%{_sbindir}/update-alternatives --install \
    %{_bindir}/profanity profanity %{_bindir}/profanity-mini 10

%preun mini
if [ "$1" = 0 ] ; then
  %{_sbindir}/update-alternatives --remove profanity %{_bindir}/profanity-mini
fi

%post standard
%{_sbindir}/update-alternatives --install \
    %{_bindir}/profanity profanity %{_bindir}/profanity-standard 20
/sbin/ldconfig

%preun standard
if [ "$1" = 0 ] ; then
  %{_sbindir}/update-alternatives --remove profanity %{_bindir}/profanity-standard
fi

%changelog
* Fri Feb  7 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.8.1:
  * Fix ending ncurses colors in rosterwin
  * Fix segfault when consistent nick colors where never in config (#1236)
  * Improve /clear behaviour to also clear the buffer. So a redraw doesn't bring
  * the content back.
  * Use unique IDs in stanzas when requesting avatars
* Mon Feb  3 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.8.0:
  * OMEMO fingerprint autocompletion now considers only the contact in question (@paulfariello) (#1068)
  * Save and display oldest timestamp from delay tags (#1254)
  * Change theme handling (#1077)
  * /theme load themename not loads only the colours of a theme. So the users preferences don't get overwritten
  * /theme full-load themename loads the whole theme including preferences (like omemo.char)
  * Add gruvbox theme (@Misaflo) (#1259)
  * XEP-0092: Include OS name in /software answer.
  * See /os on|off
  * Add option to notify about version request via XEP-0092 and XEP-0232 via adv.notify.discoversion
  * setting in configuration file.
  * Add option to display MUC name or JID in titlebar: /titlebar use [name|jid].
  * Add /roster room use command to decide whether to display the MUC name or JID in the roster:
    /roster room use name to use the name of the MUC in the roster list.
    /roster room use jid to use the jid of the MUC in the roster list.
  * Fix decryption failure for messages sent from Converse.js (@paulfariello) (#1253)
  * Fix crash when OMEMO key is misconfigured (@paulfariello) (#1239)
  * Use OMEMO for offline MUC members (@paulfariello) (#1242)
  * Fix OMEMO 1on1 chats with psi+ (@svensp) (#1247)
  * Save occupants and roster chars (#1244)
  * Add support for downloading user avatars via XEP-0084 (#1240)
  * See /avatar
  * Add last read position marker trackbar (#1238)
  * Dont print error message if a valid setting function is called (#1237)
  * When printing configuration we often use the same command as setting but without any argument.
  * So far ths displayed "Invalid usage".
  * Add support for XEP-0392 consistent color generation for nicks (@aaptel and @jubalh) (#1191)
  * See /color, /occupants color, /roster color
  * Call ncurses resize function before move function (#1235)
  * Fix error when joining IRC via biboumi (#1230)
  * Fix stanza_get_child_by_name_and_from() strcmp (#1227)
  * Fix showing own messages twice in ejabberd mucs (#1223)
  * Allow setting of status message (which actually never worked before) (b846c49)
  * /status set online "This is my text"
  * /status set away bye
  * /status set away
  * Add option to store current line in history (irssi down arrow) (#200)
  * Standardize commands (#1116):
    /tls show on|of -> /titlebar show|hide tls`
    /encwarn on|off -> /titlebar show|hide encwarn
    /titlebar show|hide resource additionally to /resource titlebar on
    /titlebar show|hide presence additionally to /presence titlebar on
    /invite <contact> -> `/invite send
    /invites -> /invite list
    /decline -> /invite decline
    /online, /away, /dnd, /chat, /xa -> /status set online etc.
    /status -> /status get
    /chlog on -> /logging chat on (#1224)
    /grlog on -> /logging group on (#1224)
    /group -> /roster group (#1229)
  * Check omemo stanza names when iterating nodes (@aszlig) (#1217)
  * Add clipboard feature. See /paste (#1216)
  * Log MUC PM messages (#1214)
  * Improve forest theme
  * Change default text colors to default instead of white (@mdosch) (#1213) (#535)
  * Fix date display in chat history (#992)
  * Log incoming MUC messages if origin-id sais they dont come from us (#1201)
  * Support XEP-0359: Unique and Stable Stanza IDs (#1207)
  * To help us identify which MUC messages were sent by us.
  * Fix double _XOPEN_SOURCE definition (@pasis) (#1206)
  * Highlight unread messages with a different color in /wins (#895)
  * New theming option cmd.wins.unread
  * Improve MUC 1:1 logging (#1184)
  * Fix user messages double logged in MUC logs (#1201)
  * Fix 26 causes for memory leaks
  * Add /clear autocompletion and improve help (#855)
  * Allow multiple instances to write to account config via /reload
  * command that reloads the config file (#627)
  * Log message carbons to log file (#1181)
  * Include PYTHON_EXTRA_LIBS in libtool config (@mzagozen) (#1200)
  * Document how to block users in MUCS (#618)
  * Keyboard switch to select the next window with unread messages (#1114) (alt + a)
  * Keyboard switches (for moving to 20 windows instead of 10 (#1114) (alt + 1234567890qwertyuio)
  * Fix MUC history detection with older Prosody versions (#1190) See https://issues.prosody.im/1416
  * statusbar.current is a new theming option for currently selected tab (@quite) (#1195)
  * Code cleanup
  * Make /info more user friendly (#1194)
  * Add solarized theme (#1175, #1198, #1199) (@mdosch)
  * Set nonblocking mode for stderr (@pasis) (#1192)
  * Log alleged roster push (6cf06dc)
  * Allow colorization of history messages (#1170)
  * See main.text.history theming option
  * Fix crash if source jid doesn't contain the node part (@pasis) (#1153)
  * Add support for 256 colors (@aaptel and @jubalh) (#1177 and many commits)
  * We use the Xterm color names. See https://jonasjacek.github.io/colors
  * Don't render (all) delayed messages as MUC history (@weiss) (#1173)
  * Add possibility to specify alternative config file (10ca3e)
  * Use profanity -c ~/path/to/other/config
  * Don't print subscribed message if contact is already in roster (#1166)
  * Only save preferences when new /save command is issued (#1146)
* Tue Sep 24 2019 mvetter@suse.com
- Update to 0.7.1:
  * Fix copyright/info displayed email
  * Fix typos in OMEMO logs
  * Fix crash when jid has no not part (#1153, #1193)
* Wed Jul 31 2019 mvetter@suse.com
- Build both mini and standard with OMEMO enabled
* Wed Jul 31 2019 mvetter@suse.com
- Update to 0.7.0:
  * Fix plugin unload return code if just one plugin fails (#995)
  * Fix several typos
  * Fix some display indentation issues (#1073)
  * Fail plugin unload if the plugin doesnt exist
  * Improve encrypted message stub header by mentioning the encryption method
  * Fix GPG encryption (#997)
  * Redraw sceen after entry of PGP key (#906)
  * Fix support for case-sensitive account names (#725)
  * Fix /me display when highlighting user in MUCs (#950)
  * Fix `make dist` (0f0659a)
  * Fix use after free bug (#1044)
  * Fix segfault on connect with default account (#1046)
  * Implement OMEMO support (#1039, #658, #1070)
  * Add random string at the end of the default resource (#1053)
  * Fix handling of messages without ID in MUC (#1061)
  * Add library versioning to libprofanity (#973)
  * Add more customization: occupants indent (/occupants) (#690, #1072)
  * Add more customization: occupants header char (/occupants) (#690, #1074)
  * Add more customization: occupants wrap (/occupants) (#690, 125ca2f)
  * Add more customization: occupants char (/occupants) (#690, #1084)
  * Fix formatting for privileges on (a666f0d)
  * Fix usage of statusbar number in theme (#1078)
  * Fix Debian 32bit tests (#1091)
  * Fix unit tests (#1092)
  * Fix infinite loop on connection loss (#1103)
  * Don't clear saved account data in session_disconnect (#1106)
  * Cancel autoping timer on disconnect or connection loss (#1105)
  * Fix SIGABRT on connection loss (#1083)
  * Only print room history for new messages upon reconnect (#704, #1110)
  * Check if valid account before setting autoconnect (#1112)
  * Improve plugin load error message, in case built without support (cc697de)
  * Iterate up to 100 logfiles (#519)
  * Fix rejoining of MUCs upon reconnect (#1120)
  * Add option to set all window related time formats (#632, #1120)
  * Always check for directory changes with sendfile auto completion (#1154)
  * Fix several memory leaks (#1130, + plenty commits)
  * For details see https://github.com/profanity-im/profanity/milestone/17
* Mon Feb 18 2019 mvetter@suse.com
- Update to 0.6.0:
  * No changes since RC1
* Wed Jan 23 2019 mvetter@suse.com
- Update to 0.6.0 RC1:
  * Allow moving vertical window positions (/titlebar, /mainwin, /statusbar, /inputwin)
  * Allow loading/unloading all plugins (/plugins)
  * Allow installing plugins from directory (/plugins)
  * Allow uninstallation of plugins (/plugins uninstall)
  * Allow update of plugins (/plugins update)
  * Theme option for status bar time (statusbar.time)
  * Case/accent insensitive autocompletion
  * Shift tab to select previous autocomplete suggestion
  * Allow searching help (/help search_all|search_any)
  * Support for Legacy SSL
  * Allow caching of rooms (/rooms cache)
  * Add autocompletion for servername when listing rooms (/rooms service)
  * Allow showing/disabling tab number in statusbar (/statusbar show)
  * Adjust configure for OpenBSD
  * Use UUIDs instead of counter for messages
  * Support basic ad-hoc commands(xep-0050) (/command)
  * Add option to trust server's certificate (/connect, /account)
  * Add possibility to close windows via prof_win_close inputrc hook
  * Bug fixes: https://github.com/boothj5/profanity/milestone/16?closed=1
* Tue Mar 20 2018 dheidler@suse.com
- Enable C and Python plugin API
* Fri Mar 16 2018 mvetter@suse.com
- Compile profanity-mini with --disable-icons:
  Since we first do the standard build we need to disable the
  icons in the later build to really get rid of the GTK dependency
* Thu Jul 13 2017 olaf@aepfle.de
- Remove unused gnutls/openssl from buildrequires
* Thu Feb  9 2017 mvetter@suse.com
- Update to 0.5.1:
  * Add prof.get_room_nick plugins api function
  * Add main.help.header theme option
  * Look for system TLS certificate path by default (/tls certpath)
  * Use service discovery to set account muc property
  * Allow clearing account muc and resource properties
  * Allow plugins to complete file paths with prof.filepath_completer_add function
  * Add encryption settings functions to plugins api
  * Allow plugins to block message sending on pre message send hooks
  * Bug fixes: https://github.com/boothj5/profanity/milestone/15?closed=1
* Sun Nov  6 2016 jengelh@inai.de
- Orthographic fixes.
- Remove useless BuildRequire on shlib package.
* Wed Nov  2 2016 dheidler@suse.de
- Switch to libmesode insted of libstrophe
  * This allows better SSL cert validation
* Thu Sep 22 2016 mvetter@suse.com
- Fixing gh/boothj5/profanity/#860:
  profanity uses parts of the new API of libstrophe. But since
  the so name wasn't bumped this doesn't get autodetected.
  Adding the requires manually: Requires: libstrophe0 >= 0.9.0
* Wed Sep 21 2016 mvetter@suse.com
- Add better information to description
- Enable tray icon in profanity-standard
* Fri Sep 16 2016 mvetter@suse.com
- Run spec-cleaner and use macros so it builds on all archs
* Fri Sep 16 2016 mvetter@suse.com
- Add profanity-rpmlintrc
* Fri Sep 16 2016 mvetter@suse.com
- Update to version 0.5.0:
  * Plugins API supporting C and Python plugins
  * SSL certificate verification (requires libmesode) (/tls)
  * HTTP file upload (xep-0363) (/sendfile)
  * Blocking command (xep-0191) (/blocked)
  * Allow auto extended away (/autoaway)
  * Include last acitvity in initial presence (xep-0256) (/lastactivity)
  * Last Activity (xep-0012) (/lastactivity)
  * Ability to run command scripts (/script)
  * Account startscript property to execute a command script on connect (/account)
  * Export roster to CSV file (/export)
  * Support for GTK tray icons (/tray)
  * User specified text triggers for chat room notifications (/notify)
  * Per chat room notification options (/notify)
  * Many new roster panel display options (/roster)
  * Time format preferences per window type (/time)
  * Edit, prepend and append to room subject (/subject)
  * Autoping timeout preference (/autoping)
  * Window navigation by window title (/win)
  * Window closing by window title (/close)
  * Account theme setting (/account)
  * Allow sending XMPP stanzas in xmlconsole window (/xmlconsole)
  * Configure level of room message notifications in console window (/console)
  * Check ~/.config/profanity/inputrc for readline settings
  * Custom readline functions for navigation key bindings
  * Autocomplete command arguments when no characters entered
- BuildRequire at least version 0.9.0 of libstrophe
- Have libprofanity.so and profapi.h in main package for now
- Add icon files
* Tue Jun 14 2016 mvetter@suse.com
- Split profanity in two packages:
  standard - the default with all features enabled
  mini - disabling notifications thus not needing X
* Thu Oct  1 2015 mvetter@suse.com
- Build with PGP enabled
- Upgrade to version 0.4.7:
  * Build against libmesode if available
  * Handle invalid SSL certificates (requires libmesode)
  * Allow auto extended away
  * Include last acitvity in initial presence (xep-0256)
  * Last Activity (xep-0012)
  libmesode is not yet packaged. So this version uses libstrophe still.
* Tue Jul  7 2015 cfarrell@suse.com
- license update: SUSE-GPL-3.0+-with-openssl-exception
  There is an exception to permit linking with openssl
* Tue Jun 16 2015 mvetter@suse.com
- Initial commit
